#ifndef RM_DEFS_H
#define RM_DEFS_H

/*
  messege types. first byte of all comm's 
  between mote and robomote (rm) is one of these.
*/
#define DUMMY 		     0x97
#define DUMMY_2          0x79
#define DUMMY_3          0x89
#define DUMMY_1		     0x98
/*  rm to mote msgs */

#define COMMAND_RECEIVED_ACK 0x12
#define COMMAND_EXECUTED     0x13
#define MOVE_RECEIVED        0x88
#define OBJECT_DETECTED      0x78
/*  mote to rm messages */
#define COMMAND_COMPLETED_ACK_RECEIVED 0x14
#define MOVE_TIME_OUT		0x15



#define RM_ALIGN             0x7f// 0x52    

#define RM_SET_VELOCITY      0x25  // 0xA0  00100101  //move commands must have atleast hamming distannce of 4 
#define RM_MOVE              0x46  // 0xA1  01000110
#define RM_SET_BIAS          0x63  // 0xA2  01100011
#define RM_SET_HEADING       0xA3         
#define RM_TURN              0xA4
#define RM_MOVETO            0xA5
#define RM_RMOVETO           0xA6
#define RM_RELATIVE_TURN     0xA7
#define NEW_AZIMUTH          0x0f // 0xA7   00001111
#define RM_SET_IR_THRESH     0xB0 // timebeing not using.

#define RM_SLEEP             0xC0
#define RM_WAKE              0xC1 
/* RoboMote state comes back to renemote after call to 
   get_state.  State is 12 bytes as follows:

   struct rm_state_struct{
     uint8_t  heading;
     uint8_t  bat_level;
     uint8_t  ir_thresh;
     uint32_t left_odo;
     uint32_t right_odo;
     uint8_t  obj_detect; // 4 msb for ir, 4 lsb for bumpers 
   }; */
#define RM_GET_STATE         0x30
#define RM_WHERE             0x31
#define RM_RWHERE            0x32

#define RM_RESET             0x40
#define RM_STOP              0x41


/* global rm_update_status is one of the following */
#define RM_RXTX_PENDING      21 /* rm_update_status = this during a "get..." */
#define RM_RXTX_COMPLETE     23 /* rm_update_status = this otherwise */



/* rm to mote megs */
#define RM_CMD_DONE          0x80    /* sent from rm to renemote when a 
				      command that takes time is finished, 
				      like moving a set distance */
#define RM_TURN_DONE         0xf1
#define REQUEST_RESEND       0x44
#define RM_OBJECT_DETECT     0x81  
#define RM_STATE_UPDATE      0x82
#define TIME_OUT             0x85
//#define TIME_OUT_ERROR       2
#define RM_HERE              0x90
#define RM_RHERE             0x91
#define RM_RXTX_ERROR        0xE0  /* rm sends back this msg iff  it 
				      times out waiting for the 2nd byte 
				      of a cmd.				    
				   */
#define RM_DEBUG             0xF0  /* et-cetera debugging messages 8 bytes */
                                   /* up to 0xEF */
				     
#define RM_STATE_PACKET_SIZE 12     /* state data size */
#define RM_MOVE_DONE 0x65
//#define RM_RX_TIMEOUT        1000  /* not a tuned value! */

#define BDRATE 19200
//#define BDRATE 9600
 
#ifdef BDRATE
# if(BDRATE == 19200)
#  define BAUDRATE             B19200
#  define BAUDDIV              12
# else // default to 9600
#  define BAUDRATE             B9600
#  define BAUDDIV              25
# endif
#else
# error "BDRATE must be defined!"
#endif // BDRATE

#define ROBO_MSG_SIZE 13
#define RENE_MSG_SIZE 9

#endif
